@@ -5,7 +5,7 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
 
-  $Id: decode.h,v 1.1 2000/05/16 17:31:14 dugsong Exp $
+  $Id: decode.h,v 1.2 2000/06/14 06:09:59 dugsong Exp $
 */
 
 #ifndef DECODE_H
@@ -25,10 +25,10 @@ struct decode *getdecodebyname(const char *name);
 			 ((u_short)*((u_char *)p+1)<<8| \
 			  (u_short)*((u_char *)p+0)<<0))
      
-#define pletohl(p)	((u_long)*((u_char *)p+3)<<24|  \
-			 (u_long)*((u_char *)p+2)<<16|  \
-			 (u_long)*((u_char *)p+1)<<8|   \
-			 (u_long)*((u_char *)p+0)<<0)
+#define pletohl(p)	((u_int32_t)*((u_char *)p+3)<<24|  \
+			 (u_int32_t)*((u_char *)p+2)<<16|  \
+			 (u_int32_t)*((u_char *)p+1)<<8|   \
+			 (u_int32_t)*((u_char *)p+0)<<0)
 
 u_char *bufbuf(u_char *big, int blen, u_char *little, int llen);
 
