@@ -5,9 +5,11 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  
-  $Id: decode_ftp.c,v 1.1 2000/05/16 17:31:14 dugsong Exp $
+  $Id: decode_ftp.c,v 1.3 2000/06/17 19:42:24 dugsong Exp $
 */
 
+#include "config.h"
+
 #include <sys/types.h>
 #include <stdio.h>
 #include <string.h>
@@ -20,8 +22,11 @@ decode_ftp(u_char *buf, int len)
 	char *p;
 	
 	Buf[0] = '\0';
+	
+	if ((len = strip_telopts(buf, len)) == 0)
+		return (0);
 
-	if (!strip_telopts(buf, len))
+	if (!is_ascii_string(buf, len))
 		return (0);
 	
 	for (p = strtok(buf, "\r\n"); p != NULL; p = strtok(NULL, "\r\n")) {
