@@ -5,9 +5,11 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  
-  $Id: decode_irc.c,v 1.1 2000/05/16 17:31:14 dugsong Exp $
+  $Id: decode_irc.c,v 1.3 2000/06/17 16:29:50 dugsong Exp $
 */
 
+#include "config.h"
+
 #include <sys/types.h>
 #include <stdio.h>
 #include <string.h>
@@ -36,7 +38,8 @@ decode_irc(u_char *buf, int len)
 		}
 		else if (strncasecmp(q, "PASS ", 5) == 0 ||
 			 strncasecmp(q, "OPER ", 5) == 0 ||
-			 (strncasecmp(q, "MODE ", 5) == 0 && strstr(q, " +k ") != NULL) ||
+			 (strncasecmp(q, "MODE ", 5) == 0 &&
+			  strstr(q, " +k ") != NULL) ||
 			 (strncasecmp(q, "JOIN ", 5) == 0 &&
 			  (q = strchr(q + 5, ' ')) != NULL && q[1] != '\0')) {
 			got_auth = 1;
@@ -44,8 +47,5 @@ decode_irc(u_char *buf, int len)
 			strlcat(Buf, "\n", sizeof(Buf));
 		}
 	}
-	if (!got_auth)
-		return (0);
-	
-	return (strlen(Buf));
+	return (got_auth ? strlen(Buf) : 0);
 }
