@@ -1,15 +1,15 @@
 /*
   decode_napster.c
 
-  Napster.
-
-  w00w00!
+  Napster. w00w00!
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  
-  $Id: decode_napster.c,v 1.1 2000/05/16 17:31:14 dugsong Exp $
+  $Id: decode_napster.c,v 1.3 2000/06/14 16:16:00 dugsong Exp $
 */
 
+#include "config.h"
+
 #include <sys/types.h>
 #include <stdio.h>
 #include <string.h>
