@@ -8,9 +8,11 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
   
-  $Id: decode_pcanywhere.c,v 1.2 2000/05/17 06:03:17 dugsong Exp $
+  $Id: decode_pcanywhere.c,v 1.4 2000/06/14 06:43:32 dugsong Exp $
 */
 
+#include "config.h"
+
 #include <sys/types.h>
 #include <stdio.h>
 #include <string.h>
@@ -24,7 +26,7 @@ decode_pcanywhere(u_char *buf, int len)
 	
 	Buf[0] = '\0';
 	
-	if (len < 6 || *(u_long *)buf != 0)
+	if (len < 6 || *(u_int32_t *)buf != 0)
 		return (0);
 	
 	/* Version 7, no encryption. */
