@@ -7,9 +7,11 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
 
-  $Id: decode_postgresql.c,v 1.1 2000/05/17 00:34:49 dugsong Exp $
+  $Id: decode_postgresql.c,v 1.3 2000/06/14 06:43:32 dugsong Exp $
 */
 
+#include "config.h"
+
 #include <sys/types.h>
 #include <stdio.h>
 #include <string.h>
@@ -20,7 +22,7 @@
 int
 decode_postgresql(u_char *buf, int len)
 {
-	u_long plen;
+	u_int32_t plen;
 	u_char *p;
 	char *db, *user;
 	
@@ -32,13 +34,13 @@ decode_postgresql(u_char *buf, int len)
 	
 	for (;;) {
 		if (len < 4) break;
-		plen = ntohl(*(u_long *) buf);
+		plen = ntohl(*(u_int32_t *) buf);
 		
 		if (plen > len)	break;
 		p = buf + 4;
 		
 		if (plen == STARTUP_PKTLEN) {
-			if (ntohl(*(u_long *)p) >> 16 == 2) {
+			if (ntohl(*(u_int32_t *)p) >> 16 == 2) {
 				db = p + 4; db[63] = '\0';
 				user = db + 64; user[31] = '\0';
 			}
