@@ -5,9 +5,11 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
   
-  $Id: decode_telnet.c,v 1.1 2000/05/16 17:31:14 dugsong Exp $
+  $Id: decode_telnet.c,v 1.3 2000/06/17 19:42:24 dugsong Exp $
 */
 
+#include "config.h"
+
 #include <sys/types.h>
 #include <stdio.h>
 #include <string.h>
@@ -17,7 +19,10 @@
 int
 decode_telnet(u_char *buf, int len)
 {
-	if (!strip_telopts(buf, len))
+	if ((len = strip_telopts(buf, len)) == 0)
+		return (0);
+
+	if (!is_ascii_string(buf, len))
 		return (0);
 	
 	if (strip_lines(buf, Opt_lines) < 2)
