@@ -5,18 +5,20 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
   
-  $Id: options.h,v 1.2 2000/05/19 05:05:55 dugsong Exp $
+  $Id: options.h,v 1.3 2000/06/14 00:29:55 dugsong Exp $
 */
 
 #ifndef OPTIONS_H
 #define OPTIONS_H
 
+extern int	Opt_client;
 extern u_short	Opt_dns;
+extern int	Opt_debug;
+extern int	Opt_magic;
 extern int	Opt_read;
 extern int	Opt_write;
 extern int	Opt_snaplen;
 extern int	Opt_lines;
-extern int	Opt_debug;
 
 #endif /* OPTIONS_H */
 
