@@ -1,17 +1,17 @@
 /*
   tcp_raw.h
 
-  Raw (best-effor, half-duplex) TCP reassembly. Haaacccck.
+  Raw (best-effort, half-duplex) TCP reassembly. Haaacccck.
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
   
-  $Id: tcp_raw.h,v 1.1 2000/05/18 20:20:04 dugsong Exp $
+  $Id: tcp_raw.h,v 1.3 2000/06/14 06:10:00 dugsong Exp $
 */
 
 #ifndef TCP_RAW_H
 #define TCP_RAW_H
 
-typedef void (*tcp_raw_callback_t)(u_long src, u_long dst,
+typedef void (*tcp_raw_callback_t)(in_addr_t src, in_addr_t dst,
 				   u_short sport, u_short dport,
 				   u_char *buf, int len);
 
